;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cond-let" "20260430.2236"
  "Additional and improved binding conditionals."
  '((emacs "28.1"))
  :url "https://github.com/tarsius/cond-let"
  :commit "28d3b039a9c1f27ecfea36a7df4c37a3b90e4687"
  :revdesc "28d3b039a9c1"
  :keywords '("extensions"))
